%LIBERTYGUI.m is the GUI file for creating the GUI.

% _______________________________________________________________________
%
%     Matlab version author: Yang Xiguang 
%     Organization: Key Laboratory of Saline-Alkali Vegetation Ecology Restoration (SAVER), Ministry of Education, Alkali Soil Natural Environmental Science Center (ASNESC), Northeast Forestry University
%     Address: No.26 Hexing road,harbin,Heilongjiang Province, China
%     Postalcode: 150040
%     E-mail: yangxiguang21@163.com or yangxiguang@nefu.edu.cn
%     Version: LIBERTY version 1.0 (Matlab) (25 May 2009)
%
% _______________________________________________________________________

close all

f1=figure(1);
set(f1,'units','normal', ...
  'Position',[0.04 0.25 0.6 0.5], ...
  'NumberTitle','off', ...
  'MenuBar','none', ...
  'Name','LIBERTY - Version 1.0');

help_text=[
  'The LIBERTY model - Version 1.0 (25 May 2009)                         ';
  'subroutines required:                                                 ';
  'LIBERTY is a general purpose radiative tranfer modelfor predicting the';
  'reflectance and transmittance spectra of a leaf, or stack of leaves in';
  'the visible and near infrared wavelengths (400 - 2500 nm). By         ';
  'treating a leaf as an aggregation of cells, with multiple radiation   ';
  'scattering  between cells, output spectra is a function of three      ';
  'structural parameters and the combined absorption coefficients of     ';
  'leaf biochemicals. It is simple to use with the user being prompted   ';
  'for input values and the model output is written to an external file  ';
  'for use with graphing and spreadsheet packages as well as for         '; 
  'coupling with vegetation canopy or ecosystem models.                  ';
  '                                                                      ';
  'It was compiled in Matlab code by Xiguang Yang.  And it was permitted ';
  'by original author Pro.Terence P.Dawson.                              ';
  '                                                                      ';
  'The project includes two functions and one data file as followed:     ';
  'LIBERTY.m, LIBERTYGUI.m and spectraldata.m                            ';
  'LIBERTY.m is the core of the LIBERTY model;                           ';
  'LIBERTYGUI.m is the GUI file for creating the GUI.                    ';
  'spectraldata.m includes absorption coefficient of in-vivo chlorophylls';
  'and carotenoids,Absorption coefficient of dried albino leaf due to    '; 
  'lignin (visible wavelengths),Water absorption coefficient,Combined    ';
  'absorption coefficient of lignin and cellulose and Protein absorption ';
  'coefficient.                                                          '; 
  'LIBERTY uses external data files. This allows the user to easily      ';
  'modify the existing absorption coefficients or provide new ones.      ';];
uic1_help=['set(f2,''units'',''normal'',', ...
    '''Position'',[0.65 0.25 0.33 0.5],', ...
    '''NumberTitle'',''off'',', ...
    '''MenuBar'',''none'',',...
    '''Name'',''Help'')'];
uic2_help=['uicontrol(f2,''Style'',''text'',', ...
    '''HorizontalAlignment'',''left'',', ...
    '''Units'',''normal'',', ...
    '''Position'',[0 0 1 1],', ...
    '''String'',help_text)'];
uicontrol(f1, ...
  'style','push', ...
  'units','normal', ...
  'position',[0.5 0.02 0.1 0.05], ...
  'FontSize',12, ...
  'string','Help', ...
  'callback',['f2=figure(2);eval(uic1_help);eval(uic2_help)']);
example_text=[
  'Model inputs are required from the user:                              ';
  '----------------------------------------------------------------------';
  'Variable        Description                Typical values(and range)  ';
  '----------------------------------------------------------------------';
  'Cell Diameter   Average leaf cell diameter (m-6)        40 (20 - 100) ';
  '----------------------------------------------------------------------';
  'Intercellular   Determinant for the amount of                         ';
  'air space    radiative flux passing between cells   0.045 (0.01 - 0.1)';
  '----------------------------------------------------------------------';
  'Leaf thickness  Arbitrary value to determine single                   ';
  '     leaf reflectance and transmittance                               ';
  '     from infinite reflectance criteria                1.6 (1 - 10)   ';
  '----------------------------------------------------------------------';
  'Baseline        Wavelength independent absorption to                  ';
  'absorption      compensate for changes in absolute     Fresh: 0.0006  ';
  '	reflectance                                            Dry: 0.0004   ';
  '----------------------------------------------------------------------';
  'Albino          Absorption in the visible region due                  ';
  'absorption      to lignin                               2 (0 - 4)     ';
  '----------------------------------------------------------------------';
  'Chlorophyll                                                           ';
  'content         Chlorophyll (pigment) content (mg.m-2)  200 (0 - 600) ';
  '----------------------------------------------------------------------';
  ' Water                                                                ';
  'content         Water content (g.m-2)                   100 (0 - 500) ';
  '----------------------------------------------------------------------';
  'Lignin and                                                            ';
  'Cellulose       Combined lignin and cellulose                         ';
  'content         content (g.m-2)                         40 (10 - 80)  ';
  '----------------------------------------------------------------------';
  'Nitrogen        Nitrogen content                                      ';
  'content         (g.m-2)                                 1 (0.3 - 2.0) ';
  '----------------------------------------------------------------------';
];
uic1_example=['set(f2,''units'',''normal'',', ...
    '''Position'',[0.65 0.25 0.34 0.5],', ...
    '''NumberTitle'',''off'',', ...
    '''MenuBar'',''none'')'];
uic2_example=['uicontrol(f2,''Style'',''text'',', ...
    '''HorizontalAlignment'',''left'',', ...
    '''Units'',''normal'',', ...
    '''FontName'',''Courier'',', ...
    '''Position'',[0 0 1 1],', ...
    '''String'',example_text)'];
uicontrol(f1, ...
  'style','push', ...
  'units','normal', ...
  'position',[0.6 0.02 0.1 0.05], ...
  'FontSize',12, ...
  'string','Example', ...
  'callback',['f2=figure(2);eval(uic1_example);eval(uic2_example)']);
uicontrol(f1, ...
  'style','push', ...
  'units','normal', ...
  'position',[0.7 0.02 0.1 0.05], ...
  'FontSize',12, ...
  'string','Save', ...
  'callback',['[fname,pname]=uiputfile(''*.dat'',''Save file name'');', ...
    'if fname~=0;', ...
         'file=fopen([pname fname],''wt'');', ...
         'fprintf(file,''%s %s %s %s\n'',''wavelength'',''infinate leaf reflectance'',''reflectance'',''Transmittance'');',...
         'fprintf(file,''%6.1f %6.4f %6.4f %6.4f\n'',LRT'');', ...
         'fclose(file);', ...
         'end']);
uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'position',[0.1 0.93 0.2 0.05], ...
  'backgroundcolor','green', ...
  'FontSize',12, ...
  'FontWeight','bold', ...
  'string','LIBERTY', ...
  'horiz','center');

uicontrol(f1, ...
  'style','push', ...
  'units','normal', ...
  'position',[0.8 0.02 0.1 0.05], ... 
  'FontSize',12, ...
  'string','Close', ...
  'callback','close all');

axes('Position',[0.45 0.165 0.5 0.7]);
LRT=LIBERTY(40,0.045,1.6,0.0005,2,200,100,40,1);
plot(LRT(:,1),LRT(:,2),'-b',LRT(:,1),LRT(:,3),'-r',LRT(:,1),LRT(:,4),'-g');
xlabel('Wavelength (nm)')
h=legend('Infinite Leaf Reflectance','Single Reflectance','Transmittance');
set(h,'Position',[0.592 0.81 0.24 0.09]);
axis([400 2500 0 1])

protext=['LRT=LIBERTY(get(sli_D,''value''),get(sli_Ias,''value''),get(sli_thickness,''value''),get(sli_Baseline,''value''),get(sli_albino,''value''),get(sli_Chlorophyll,''value''),get(sli_Water,''value''),get(sli_Lignin_Cellulose,''value''),get(sli_Nitrogen,''value''));', ...
  'plot(LRT(:,1),LRT(:,2),''-b'',LRT(:,1),LRT(:,3),''-r'',LRT(:,1),LRT(:,4),''-g'');', ...
  'xlabel(''Wavelength (nm)'');', ...
  'h=legend(''Infinite Leaf Reflectance'',''Reflectance'',''Transmittance'');', ...
  'set(h,''Position'',[0.592 0.81 0.24 0.09]);', ...
  'axis([400 2500 0 1])'];
%--------------------------------------------------------------------------
%Cell Diameter Dm-6 20-100
%--------------------------------------------------------------------------
D_text1='set(D_hand,''string'',num2str(get(sli_D,''value'')));';
D_text11='set(D_hand,''string'',num2str(get(sli_D,''min'')));';
D_text12='set(D_hand,''string'',num2str(get(sli_D,''max'')));';
D_text2='set(sli_D,''value'',D_value);';
sli_D=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.82 0.2 0.04], ...
  'min',20,'max',100,'value',40, ...
  'callback',[D_text1,protext]);
D_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.82 0.06 0.04], ...
  'string',num2str(get(sli_D,'min')), ...
  'horiz','center');
D_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.82 0.06 0.04], ...
  'string',num2str(get(sli_D,'max')), ...
  'horiz','center');
D_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.86 0.22 0.04], ...
  'string','leaf cell diameter = ', ...
  'horiz','right', ...
  'backgroundcolor','yellow');
D_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.86 0.10 0.04], ...
  'string',num2str(get(sli_D,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['D_value=str2num(get(gco,''string''));', ...
    'if D_value<20;D_value=20;eval(D_text11);end;', ...
    'if D_value>100;D_value=100;eval(D_text12);end;', ...
    'eval(D_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Intercellular air space 0.01-0.1
%--------------------------------------------------------------------------

Ias_text1='set(Ias_hand,''string'',num2str(get(sli_Ias,''value'')));';
Ias_text11='set(Ias_hand,''string'',num2str(get(sli_Ias,''min'')));';
Ias_text12='set(Ias_hand,''string'',num2str(get(sli_Ias,''max'')));';
Ias_text2='set(sli_Ias,''value'',Ias_value);';
sli_Ias=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.72 0.2 0.04], ...
  'min',0.01,'max',0.1,'value',0.0450, ...
  'callback',[Ias_text1,protext]);
Ias_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.72 0.06 0.04], ...
  'string',num2str(get(sli_Ias,'min')), ...
  'horiz','center');
Ias_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.72 0.06 0.04], ...
  'string',num2str(get(sli_Ias,'max')), ...
  'horiz','center');
Ias_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.76 0.22 0.04], ...
  'string',['Intercellular air space = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
Ias_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.76 0.10 0.04], ...
  'string',num2str(get(sli_Ias,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['Ias_value=str2num(get(gco,''string''));', ...
    'if Ias_value<0.01;Ias_value=0.01;eval(Ias_text11);end;', ...
    'if Ias_value>0.1;Ias_value=0.1;eval(Ias_text12);end;', ...
    'eval(Ias_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Leaf thickness 1-10
%--------------------------------------------------------------------------

thickness_text1='set(thickness_hand,''string'',num2str(get(sli_thickness,''value'')));';
thickness_text11='set(thickness_hand,''string'',num2str(get(sli_thickness,''min'')));';
thickness_text12='set(thickness_hand,''string'',num2str(get(sli_thickness,''max'')));';
thickness_text2='set(sli_thickness,''value'',thickness_value);';
sli_thickness=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.62 0.2 0.04], ...
  'min',1,'max',10,'value',1.6, ...
  'callback',[thickness_text1,protext]);
thickness_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.62 0.06 0.04], ...
  'string',num2str(get(sli_thickness,'min')), ...
  'horiz','center');
thickness_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.62 0.06 0.04], ...
  'string',num2str(get(sli_thickness,'max')), ...
  'horiz','center');
thickness_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.66 0.22 0.04], ...
  'string',['Leaf thickness = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
thickness_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.66 0.10 0.04], ...
  'string',num2str(get(sli_thickness,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['thickness_value=str2num(get(gco,''string''));', ...
    'if thickness_value<1;thickness_value=1;eval(thickness_text11);end;', ...
    'if thickness_value>10;thickness_value=10;eval(thickness_text12);end;', ...
    'eval(thickness_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Baseline absorption  Fresh: 0.0006 Dry: 0.0004 0.0004-0.0006
%--------------------------------------------------------------------------

Baseline_text1='set(Baseline_hand,''string'',num2str(get(sli_Baseline,''value'')));';
Baseline_text11='set(Baseline_hand,''string'',num2str(get(sli_Baseline,''min'')));';
Baseline_text12='set(Baseline_hand,''string'',num2str(get(sli_Baseline,''max'')));';
Baseline_text2='set(sli_Baseline,''value'',Baseline_value);';
sli_Baseline=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.52 0.2 0.04], ...
  'min',0.0004,'max',0.0006,'value',0.0005, ...
  'callback',[Baseline_text1,protext]);
Baseline_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.52 0.06 0.04], ...
  'string',num2str(get(sli_Baseline,'min')), ...
  'horiz','center');
Baseline_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.52 0.06 0.04], ...
  'string',num2str(get(sli_Baseline,'max')), ...
  'horiz','center');
Baseline_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.56 0.22 0.04], ...
  'string',['Baseline absorption = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
Baseline_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.56 0.10 0.04], ...
  'string',num2str(get(sli_Baseline,'value')), ...
  'horiz','right', ...
  'backgroundcolor','yellow', ...
  'callback',['dry_value=str2num(get(gco,''string''));', ...
    'if Baseline_value<0.0004;Baseline_value=0.0004;eval(Baseline_text11);end;', ...
    'if Baseline_value>0.0006;Baseline_value=0.0006;eval(Baseline_text12);end;', ...
    'eval(Baseline_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Albino leaf 2 (0 - 4)
%--------------------------------------------------------------------------
albino_text1='set(albino_hand,''string'',num2str(get(sli_albino,''value'')));';
albino_text11='set(albino_hand,''string'',num2str(get(sli_albino,''min'')));';
albino_text12='set(albino_hand,''string'',num2str(get(sli_albino,''max'')));';
albino_text2='set(sli_albino,''value'',albino_value);';
sli_albino=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.42 0.2 0.04], ...
  'min',0,'max',4,'value',2, ...
  'callback',[albino_text1,protext]);
albino_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.42 0.06 0.04], ...
  'string',num2str(get(sli_albino,'min')), ...
  'horiz','center');
albino_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.42 0.06 0.04], ...
  'string',num2str(get(sli_albino,'max')), ...
  'horiz','center');
albino_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.46 0.22 0.04], ...
  'string',['Albino leaf = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
albino_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.46 0.10 0.04], ...
  'string',num2str(get(sli_albino,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['albino_value=str2num(get(gco,''string''));', ...
    'if albino_value<0;albino_value=00;eval(albino_text11);end;', ...
    'if albino_value>4;albino_value=4;eval(albino_text12);end;', ...
    'eval(albino_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Chlorophyll a+b content (mg.m-2) 200 (0 - 600)
%--------------------------------------------------------------------------
Chlorophyll_text1='set(Chlorophyll_hand,''string'',num2str(get(sli_Chlorophyll,''value'')));';
Chlorophyll_text11='set(Chlorophyll_hand,''string'',num2str(get(sli_Chlorophyll,''min'')));';
Chlorophyll_text12='set(Chlorophyll_hand,''string'',num2str(get(sli_Chlorophyll,''max'')));';
Chlorophyll_text2='set(sli_Chlorophyll,''value'',Chlorophyll_value);';
sli_Chlorophyll=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.32 0.2 0.04], ...
  'min',0,'max',600,'value',200, ...
  'callback',[Chlorophyll_text1,protext]);
Chlorophyll_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.32 0.06 0.04], ...
  'string',num2str(get(sli_Chlorophyll,'min')), ...
  'horiz','center');
Chlorophyll_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.32 0.06 0.04], ...
  'string',num2str(get(sli_Chlorophyll,'max')), ...
  'horiz','center');
Chlorophyll_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.36 0.22 0.04], ...
  'string',['Chlorophyll content = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
Chlorophyll_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.36 0.10 0.04], ...
  'string',num2str(get(sli_Chlorophyll,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['Chlorophyll_value=str2num(get(gco,''string''));', ...
    'if Chlorophyll_value<0;Chlorophyll_value=0;eval(Chlorophyll_text11);end;', ...
    'if Chlorophyll_value>600;Chlorophyll_value=600;eval(Chlorophyll_text12);end;', ...
    'eval(Chlorophyll_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Water content (g.m-2) 100 (0 - 500)
%--------------------------------------------------------------------------
Water_text1='set(Water_hand,''string'',num2str(get(sli_Water,''value'')));';
Water_text11='set(Water_hand,''string'',num2str(get(sli_Water,''min'')));';
Water_text12='set(Water_hand,''string'',num2str(get(sli_Water,''max'')));';
Water_text2='set(sli_Water,''value'',Water_value);';
sli_Water=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.22 0.2 0.04], ...
  'min',0,'max',500,'value',100, ...
  'callback',[Chlorophyll_text1,protext]);
Water_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.22 0.06 0.04], ...
  'string',num2str(get(sli_Water,'min')), ...
  'horiz','center');
Water_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.22 0.06 0.04], ...
  'string',num2str(get(sli_Water,'max')), ...
  'horiz','center');
Water_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.26 0.22 0.04], ...
  'string',['Water content = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
Water_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.26 0.10 0.04], ...
  'string',num2str(get(sli_Water,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['Water_value=str2num(get(gco,''string''));', ...
    'if Water_value<0;Water_value=0;eval(Water_text11);end;', ...
    'if Water_value>500;Water_value=500;eval(Water_text12);end;', ...
    'eval(Water_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Lignin and Cellulose content (g.m-2) 40 (10 - 80)
%--------------------------------------------------------------------------
Lignin_Cellulose_text1='set(Lignin_Cellulose_hand,''string'',num2str(get(sli_Lignin_Cellulose,''value'')));';
Lignin_Cellulose_text11='set(Lignin_Cellulose_hand,''string'',num2str(get(sli_Lignin_Cellulose,''min'')));';
Lignin_Cellulose_text12='set(Lignin_Cellulose_hand,''string'',num2str(get(sli_Lignin_Cellulose,''max'')));';
Lignin_Cellulose_text2='set(sli_Lignin_Cellulose,''value'',Lignin_Cellulose_value);';
sli_Lignin_Cellulose=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.12 0.2 0.04], ...
  'min',10,'max',80,'value',40, ...
  'callback',[Lignin_Cellulose_text1,protext]);
Lignin_Cellulose_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.12 0.06 0.04], ...
  'string',num2str(get(sli_Lignin_Cellulose,'min')), ...
  'horiz','center');
Lignin_Cellulose_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.12 0.06 0.04], ...
  'string',num2str(get(sli_Lignin_Cellulose,'max')), ...
  'horiz','center');
Lignin_Cellulose_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.16 0.22 0.04], ...
  'string',['Lignin&Cellulose content = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
Lignin_Cellulose_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.16 0.10 0.04], ...
  'string',num2str(get(sli_Lignin_Cellulose,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['Lignin_Cellulose_value=str2num(get(gco,''string''));', ...
    'if Lignin_Cellulose_value<10;Lignin_Cellulose_value=10;eval(Lignin_Cellulose_text11);end;', ...
    'if Lignin_Cellulose_value>80;Lignin_Cellulose_value=80;eval(Lignin_Cellulose_text12);end;', ...
    'eval(Lignin_Cellulose_text2);eval(protext)']);
%--------------------------------------------------------------------------
%Nitrogen content (g.m-2) 1 (0.3 - 2.0)
%--------------------------------------------------------------------------
Nitrogen_text1='set(Nitrogen_hand,''string'',num2str(get(sli_Nitrogen,''value'')));';
Nitrogen_text11='set(Nitrogen_hand,''string'',num2str(get(sli_Nitrogen,''min'')));';
Nitrogen_text12='set(Nitrogen_hand,''string'',num2str(get(sli_Nitrogen,''max'')));';
Nitrogen_text2='set(sli_Nitrogen,''value'',Nitrogen_value);';
sli_Nitrogen=uicontrol(f1, ...
  'style','slider', ...
  'units','normal', ...
  'position',[0.1 0.02 0.2 0.04], ...
  'min',0.3,'max',2.0,'value',1, ...
  'callback',[Nitrogen_text1,protext]);
Nitrogen_min=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.02 0.06 0.04], ...
  'string',num2str(get(sli_Nitrogen,'min')), ...
  'horiz','center');
Nitrogen_max=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.3 0.02 0.06 0.04], ...
  'string',num2str(get(sli_Nitrogen,'max')), ...
  'horiz','center');
Nitrogen_label=uicontrol(f1, ...
  'style','text', ...
  'units','normal', ...
  'pos',[0.04 0.06 0.22 0.04], ...
  'string',['Nitrogen content = '], ...
  'horiz','right', ...
  'backgroundcolor','yellow');
Nitrogen_hand=uicontrol(f1, ...
  'style','edit', ...
  'units','normal', ...
  'pos',[0.26 0.06 0.10 0.04], ...
  'string',num2str(get(sli_Nitrogen,'value')), ...
  'horiz','left', ...
  'backgroundcolor','yellow', ...
  'callback',['Nitrogen_value=str2num(get(gco,''string''));', ...
    'if Nitrogen_value<0.3;Nitrogen_value=0.3;eval(Nitrogen_text11);end;', ...
    'if Nitrogen_value>80;Nitrogen_value=80;eval(Nitrogen_text12);end;', ...
    'eval(Nitrogen_text2);eval(protext)']);



